@@ -9,11 +9,15 @@ from _base import BaseExporter
 
 
 class ExcelExporter(BaseExporter):
+    short_name = 'Excel'
+    long_name = 'Microsoft Excel 2007 Format'
+
     file_extension = 'xlsx'
     content_type = 'application/vnd.ms-excel'
-    preferred_formats = ('boolean', 'number', 'string')
 
-    def write(self, iterable, buff=None):
+    preferred_formats = ('excel', 'boolean', 'number', 'string')
+
+    def write(self, iterable, buff=None, *args, **kwargs):
         buff = self.get_file_obj(buff)
 
         wb = Workbook(optimized_write=True)
@@ -23,7 +27,7 @@ class ExcelExporter(BaseExporter):
 
         header = []
         # Create the data worksheet
-        for i, row_gen in enumerate(self.read(iterable)):
+        for i, row_gen in enumerate(self.read(iterable, *args, **kwargs)):
             row = []
             for data in row_gen:
                 if i == 0:
