@@ -16,7 +16,7 @@ class LexiconManager(models.Manager):
     def reorder(self, cmp=None, key=None):
         if isinstance(key, basestring):
             if key not in key_funcs:
-                raise KeyError('No key function named {0}'.format(key))
+                raise KeyError(u'No key function named {0}'.format(key))
             key = key_funcs[key]
         items = list(self.get_query_set())
         items.sort(cmp=cmp, key=key)
