@@ -483,6 +483,8 @@ class DataContext(AbstractDataContext, Base):
     This corresponds to the `WHERE` statements in a SQL query.
     """
     session = models.BooleanField(default=False)
+    template = models.BooleanField(default=False)
+    default = models.BooleanField(default=False)
 
     # For authenticated users the `user` can be directly referenced,
     # otherwise the session key can be used.
@@ -490,6 +492,8 @@ class DataContext(AbstractDataContext, Base):
     session_key = models.CharField(max_length=40, null=True, blank=True)
 
     def __unicode__(self):
+        if self.name:
+            return self.name
         if self.user_id:
             out = unicode(self.user)
         else:
@@ -505,6 +509,19 @@ class DataContext(AbstractDataContext, Base):
         self.pk, self.session, self.archived = backup
         return True
 
+    def clean(self):
+        from django.core.exceptions import ValidationError
+        if self.template and self.default:
+            queryset = self.__class__.objects.filter(template=True, default=True)
+            if self.pk:
+                queryset = queryset.exclude(pk=self.pk)
+            if queryset.exists():
+                raise ValidationError('Only one default template can be defined')
+
+    def save(self, *args, **kwargs):
+        self.clean()
+        super(self.__class__, self).save(*args, **kwargs)
+
 
 class DataView(AbstractDataView, Base):
     """JSON object representing one or more data field conditions. The data may
@@ -513,6 +530,8 @@ class DataView(AbstractDataView, Base):
     This corresponds to the `SELECT` and `ORDER BY` statements in a SQL query.
     """
     session = models.BooleanField(default=False)
+    template = models.BooleanField(default=False)
+    default = models.BooleanField(default=False)
 
     # For authenticated users the `user` can be directly referenced,
     # otherwise the session key can be used.
@@ -520,7 +539,9 @@ class DataView(AbstractDataView, Base):
     session_key = models.CharField(max_length=40, null=True, blank=True)
 
     def __unicode__(self):
-        if self.user_id:
+        if self.name:
+            return self.name
+        elif self.user_id:
             out = unicode(self.user)
         else:
             out = self.session_key
@@ -535,6 +556,19 @@ class DataView(AbstractDataView, Base):
         self.pk, self.session, self.archived = backup
         return True
 
+    def clean(self):
+        from django.core.exceptions import ValidationError
+        if self.template and self.default:
+            queryset = self.__class__.objects.filter(template=True, default=True)
+            if self.pk:
+                queryset = queryset.exclude(pk=self.pk)
+            if queryset.exists():
+                raise ValidationError('Only one default template can be defined')
+
+    def save(self, *args, **kwargs):
+        self.clean()
+        super(self.__class__, self).save(*args, **kwargs)
+
 
 # Register instance-level cache invalidation handlers
 post_save.connect(post_save_cache, sender=DataField)
