@@ -12,29 +12,36 @@ class AbstractDataContext(models.Model):
     """
     json = jsonfield.JSONField(null=True, blank=True, default=dict,
         validators=[parsers.datacontext.validate])
-    composite = models.BooleanField(default=False)
     count = models.IntegerField(null=True, db_column='_count')
 
+    def __init__(self, *args, **kwargs):
+        if args and isinstance(args[0], dict):
+            if 'json' in kwargs:
+                raise TypeError("{0}.__init__() got multiple values for keyword argument 'json'".format(self.__class__.__name__))
+            args = list(args)
+            kwargs['json'] = args.pop(0)
+        super(AbstractDataContext, self).__init__(*args, **kwargs)
+
     class Meta(object):
         abstract = True
 
     def _combine(self, other, operator):
         if not isinstance(other, self.__class__):
             raise TypeError('Other object must be a DataContext instance')
-        cxt = self.__class__(composite=True)
+        cxt = self.__class__()
         cxt.user_id = self.user_id or other.user_id
         if self.json and other.json:
             cxt.json = {
                 'type': operator,
                 'children': [
-                    {'id': self.pk, 'composite': True},
-                    {'id': other.pk, 'composite': True}
+                    {'composite': self.pk},
+                    {'composite': other.pk}
                 ]
             }
         elif self.json:
-            cxt.json = {'id': self.pk, 'composite': True}
+            cxt.json = {'composite': self.pk}
         elif other.json:
-            cxt.json = {'id': other.pk, 'composite': True}
+            cxt.json = {'composite': other.pk}
         return cxt
 
     def __and__(self, other):
@@ -78,6 +85,14 @@ class AbstractDataView(models.Model):
         validators=[parsers.dataview.validate])
     count = models.IntegerField(null=True, db_column='_count')
 
+    def __init__(self, *args, **kwargs):
+        if args and isinstance(args[0], dict):
+            if 'json' in kwargs:
+                raise TypeError("{0}.__init__() got multiple values for keyword argument 'json'".format(self.__class__.__name__))
+            args = list(args)
+            kwargs['json'] = args.pop(0)
+        super(AbstractDataView, self).__init__(*args, **kwargs)
+
     class Meta(object):
         abstract = True
 
