@@ -65,25 +65,31 @@ class ContainerTypeOperator(BaseOperator):
 
     def text(self, value):
         value = map(self.coerce_to_unicode, value)
+        length = len(value)
 
-        last = value[-1]
-        length = len(value) - 1
+        if length == 1:
+            if self.negated:
+                name = NotExact.verbose_name
+            else:
+                name = Exact.verbose_name
+            return u'{0} {1}'.format(name, value[0])
 
-        if length == 0:
-            return u'{0} {1}'.format(self.verbose_name, last)
+        last = value.pop()
+        length -= 1
 
         if length > self.max_list_size:
             head = value[:self.max_list_size]
         else:
-            head = value[:-1]
-        text = self.verbose_name + ' ' + ', '.join(head)
+            head = value
+
+        text = '{0} {1}'.format(self.verbose_name, ', '.join(head))
 
         # Add the leftover item count for the tail of the list
         tail = length - self.max_list_size
         if tail > 0:
             text += u' ... ({0} more)'.format(tail)
 
-        return text + u' {0} '.format(self.join_string) + last
+        return u'{0} {1} {2}'.format(text, self.join_string, last)
 
 
 class Null(BaseOperator):
@@ -143,24 +149,22 @@ class InsensitiveNotExact(InsensitiveExact):
 class Contains(StringOperator):
     lookup = 'contains'
     short_name = 'contains'
-    verbose_name = short_name
+    verbose_name = 'contains the text'
 
 
 class InsensitiveContains(Contains):
     lookup = 'icontains'
-    short_name = 'contains'
-    verbose_name = short_name
 
 
 class NotContains(Contains):
     short_name = 'does not contain'
-    verbose_name = 'does not contain'
+    verbose_name = 'does not contain the text'
     negated = True
 
 
 class NotInsensitiveContains(InsensitiveContains):
     short_name = 'does not contain'
-    verbose_name = 'does not contain'
+    verbose_name = 'does not contain the text'
     negated = True
 
 
@@ -192,13 +196,15 @@ class GreaterThanOrEqual(SimpleTypeOperator):
 # Operators for container types (excluding strings)
 class InList(ContainerTypeOperator):
     lookup = 'in'
+    join_string = 'or'
     short_name = 'includes'
-    verbose_name = 'includes'
+    verbose_name = 'is either'
 
 
 class NotInList(InList):
+    join_string = 'nor'
     short_name = 'excludes'
-    verbose_name = 'excludes'
+    verbose_name = 'is neither'
     negated = True
 
 
